==> eam-wshub-proxyclient-11.5-10-sources.jar: net/datastream/schemas/mp_fields/PROPERTYINFORMATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour PROPERTYINFORMATIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PROPERTYINFORMATIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROPERTY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPECODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PROPERTYINFORMATIONID_Type", propOrder = {
    "property",
    "typecode"
})
public class PROPERTYINFORMATIONID_Type {

    @XmlElement(name = "PROPERTY", required = true)
    protected String property;
    @XmlElement(name = "TYPECODE", required = true)
    protected String typecode;

    /**
     * Obtient la valeur de la propriété property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROPERTY() {
        return property;
    }

    /**
     * Définit la valeur de la propriété property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROPERTY(String value) {
        this.property = value;
    }

    /**
     * Obtient la valeur de la propriété typecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTYPECODE() {
        return typecode;
    }

    /**
     * Définit la valeur de la propriété typecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTYPECODE(String value) {
        this.typecode = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/PROPERTYINFORMATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PROPERTYINFORMATIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PROPERTYINFORMATIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROPERTY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPECODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PROPERTYINFORMATIONID_Type", propOrder = {
    "property",
    "typecode"
})
public class PROPERTYINFORMATIONID_Type {

    @XmlElement(name = "PROPERTY", required = true)
    protected String property;
    @XmlElement(name = "TYPECODE", required = true)
    protected String typecode;

    /**
     * Gets the value of the property property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROPERTY() {
        return property;
    }

    /**
     * Sets the value of the property property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROPERTY(String value) {
        this.property = value;
    }

    /**
     * Gets the value of the typecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTYPECODE() {
        return typecode;
    }

    /**
     * Sets the value of the typecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTYPECODE(String value) {
        this.typecode = value;
    }

}
